@@ -1,5 +1,5 @@
 as.mcmc.blca.gibbs <-
-function(x){
+function(x, ...){
 
 #	if(class(fit)[1]!= "blca.gibbs") stop("Invalid Class, must be blca.gibbs object")
 	if(inherits(x, "blca.gibbs", TRUE) == 0) stop("Invalid Class, must be blca.gibbs object")
@@ -10,6 +10,6 @@ function(x){
   colnames(y)<-paste(rep("ClassProb",G),1:G)
   for(g in 1:G) y<-cbind(y,x$samples$itemprob[,g,])
   colnames(y)[(G+1):(G+G*M)]<-paste(rep("ItemProb",G*M), rep(1:G, each=M), rep(1:M,G) )
-  as.mcmc(y)
+  as.mcmc(y, ...)
   }
 }
